#
# spec file for package python-pook
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# requires python-aiohttp
%{?sle15_python_module_pythons}
Name:           python-pook
Version:        1.1.1
Release:        2.5
Summary:        HTTP traffic mocking and expectations
License:        MIT
URL:            https://github.com/h2non/pook
Source:         https://files.pythonhosted.org/packages/source/p/pook/pook-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-aiohttp
Requires:       python-furl >= 0.5.6
Requires:       python-jsonschema >= 2.5.1
Requires:       python-xmltodict >= 0.11.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module aiohttp}
BuildRequires:  %{python_module furl >= 0.5.6}
BuildRequires:  %{python_module jsonschema >= 2.5.1}
BuildRequires:  %{python_module mocket >= 1.6.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module urllib3 >= 1.19.1}
BuildRequires:  %{python_module xmltodict >= 0.10.2}
# /SECTION
%python_subpackages

%description
HTTP traffic mocking and expectations.

%prep
%autosetup -p1 -n pook-%{version}
rm -f setup.cfg pytest.ini tox.ini

# Assist unittest on Python 2
touch tests/__init__.py

%build
%python_build

%install
%python_install
%{python_expand rm -r %{buildroot}%{$python_sitelib}/tests/
%fdupes %{buildroot}%{$python_sitelib}
}

%check
%{python_expand  #
export PYTHONPATH=%{buildroot}%{$python_sitelib}
$python -m pytest -v tests/unit
$python -m pytest -v tests/integration/engines/pytest_suite.py
export PYTHONPATH=%{buildroot}%{$python_sitelib}:.
$python -m unittest tests.integration.engines.unittest_suite
}

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/pook
%{python_sitelib}/pook-%{version}*-info

%changelog
* Fri Dec 29 2023 Antonio Larrosa <alarrosa@suse.com>
- Use %%{?sle15_python_module_pythons}
* Fri Jan 13 2023 Daniel Garcia <daniel.garcia@suse.com>
- Remove py311-compat.patch, not needed anymore
- Update to 1.1.1:
  * Fix Py3.11 compatibility (#85)
* Thu Jan 12 2023 Daniel Garcia <daniel.garcia@suse.com>
- Add py311-compat.patch to fix python-3.11 compatibility
- Update to 1.1.0:
  * chore(version): bump minor v1.1.0
  * Switch to Python >= 3.5 and fix latest aiohttp compatability (#83)
  * fix: remove print call (#81)
* Wed Apr  6 2022 pgajdos@suse.com
- python-mock not required for build
* Mon Sep 20 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.0.2:
  * fix(urllib3): interceptor is never really disabled (#68)
  * Closes #75 Re consider @fluent decorator (#76)
  * fix(#69): use match keyword in pytest.raises
  * fix(History): invalid rst syntax
  * fix(aiohttp): compatible with non aiohttp projects (#67)
  * feat(History): add release changes
- Drop pytest5.patch, no longer required.
- Drop nose BuildRequires, and its suite, the remainder covers it.
* Wed May  6 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch to work with pytest5:
  * pytest5.patch
* Tue Mar 24 2020 pgajdos@suse.com
- version update to 1.0.0
  * fix(aiohttp): use latest version, allow Python 3.5+ for async http client
- drop python2 support, python-aiohttp required
* Wed Mar 18 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 0.2.8
  * fix collections import warning
* Fri Apr 19 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v0.2.6
